from _typeshed import Incomplete

from networkx.utils.backends import _dispatchable

@_dispatchable
def maximal_independent_set(G, nodes: Incomplete | None = None, seed: Incomplete | None = None): ...
