from _typeshed import Incomplete

__all__ = ["load_taiga_nplus1_metas", "load_taiga_nplus1"]

def load_taiga_nplus1_metas(path, offset: int = 0, count: int = 1): ...
def load_taiga_nplus1(path, metas: Incomplete | None = None, offset: int = 1919488, count: int = 7696): ...
