from .arzamas import *
from .fontanka import *
from .interfax import *
from .kp import *
from .lenta import *
from .magazines import *
from .nplus1 import *
from .proza import *
from .social import *
from .subtitles import *
