from networkx.utils.backends import _dispatchable

@_dispatchable
def d_separated(G, x, y, z): ...
@_dispatchable
def minimal_d_separator(G, u, v): ...
@_dispatchable
def is_minimal_d_separator(G, u, v, z): ...
