from _typeshed import Incomplete

from networkx.utils.backends import _dispatchable

@_dispatchable
def min_edge_cover(G, matching_algorithm: Incomplete | None = None): ...
@_dispatchable
def is_edge_cover(G, cover): ...
