from networkx.utils.backends import _dispatchable

@_dispatchable
def maximum_independent_set(G): ...
@_dispatchable
def max_clique(G): ...
@_dispatchable
def clique_removal(G): ...
@_dispatchable
def large_clique_size(G): ...
