from _typeshed import Incomplete

__all__ = ["load_taiga_interfax_metas", "load_taiga_interfax"]

def load_taiga_interfax_metas(path, offset: int = 0, count: int = 1): ...
def load_taiga_interfax(path, metas: Incomplete | None = None, offset: int = 11447296, count: int = 46429): ...
