from _typeshed import Incomplete

class AuthlibDeprecationWarning(DeprecationWarning): ...

def deprecate(
    message, version: Incomplete | None = None, link_uid: Incomplete | None = None, link_file: Incomplete | None = None
) -> None: ...
