from networkx.utils.backends import _dispatchable

@_dispatchable
def is_regular(G): ...
@_dispatchable
def is_k_regular(G, k): ...
@_dispatchable
def k_factor(G, k, matching_weight: str = "weight"): ...
