from _typeshed import Incomplete

from networkx.utils.backends import _dispatchable

@_dispatchable
def margulis_gabber_galil_graph(n, create_using: Incomplete | None = None): ...
@_dispatchable
def chordal_cycle_graph(p, create_using: Incomplete | None = None): ...
@_dispatchable
def paley_graph(p, create_using: Incomplete | None = None): ...
