from _typeshed import Incomplete

from networkx.utils.backends import _dispatchable

@_dispatchable
def modularity_matrix(G, nodelist: Incomplete | None = None, weight: Incomplete | None = None): ...
@_dispatchable
def directed_modularity_matrix(G, nodelist: Incomplete | None = None, weight: Incomplete | None = None): ...
