from networkx.utils.backends import _dispatchable

@_dispatchable
def degree_centrality(G, nodes): ...
@_dispatchable
def betweenness_centrality(G, nodes): ...
@_dispatchable
def closeness_centrality(G, nodes, normalized: bool = True): ...
