from _typeshed import Incomplete

__all__ = ["load_taiga_arzamas_metas", "load_taiga_arzamas"]

def load_taiga_arzamas_metas(path, offset: int = 0, count: int = 1): ...
def load_taiga_arzamas(path, metas: Incomplete | None = None, offset: int = 144896, count: int = 311): ...
