from networkx.utils.backends import _dispatchable

@_dispatchable
def union_all(graphs, rename=()): ...
@_dispatchable
def disjoint_union_all(graphs): ...
@_dispatchable
def compose_all(graphs): ...
@_dispatchable
def intersection_all(graphs): ...
