from _typeshed import Incomplete

def prepare_headers(oauth_params, headers: Incomplete | None = None, realm: Incomplete | None = None): ...
def prepare_form_encoded_body(oauth_params, body): ...
def prepare_request_uri_query(oauth_params, uri): ...
