from _typeshed import Incomplete

from networkx.utils.backends import _dispatchable

@_dispatchable
def spectral_graph_forge(G, alpha, transformation: str = "identity", seed: Incomplete | None = None): ...
