from networkx.utils.backends import _dispatchable

@_dispatchable
def subgraph_centrality_exp(G): ...
@_dispatchable
def subgraph_centrality(G): ...
@_dispatchable
def communicability_betweenness_centrality(G): ...
@_dispatchable
def estrada_index(G): ...
