from _typeshed import Incomplete
from collections.abc import Generator

COMMANDS: Incomplete
KB: int
MB: Incomplete
GB: Incomplete
LABELS: Incomplete

def is_command(step, commands=("wget", "unzip", "unrar", "rm", "mv", "tar")): ...
def format_bytes(value): ...
def format_count(value): ...
def unfold_metas(items) -> Generator[Incomplete]: ...
def format_metas_(metas, nbviewer: Incomplete | None = None) -> Generator[Incomplete]: ...
def format_metas(metas, url: Incomplete | None = None): ...
def show_html(html) -> None: ...
def patch_readme(html, path) -> None: ...
