from _typeshed import Incomplete

__all__ = ["load_taiga_lenta_metas", "load_taiga_lenta"]

def load_taiga_lenta_metas(path, offset: int = 0, count: int = 1): ...
def load_taiga_lenta(path, metas: Incomplete | None = None, offset: int = 12800000, count: int = 36446): ...
