from _typeshed import Incomplete

from networkx.utils.backends import _dispatchable

@_dispatchable
def rich_club_coefficient(G, normalized: bool = True, Q: float = 100, seed: Incomplete | None = None): ...
