from _typeshed import Incomplete

__all__ = ["load_taiga_kp_metas", "load_taiga_kp"]

def load_taiga_kp_metas(path, offset: int = 0, count: int = 1): ...
def load_taiga_kp(path, metas: Incomplete | None = None, offset: int = 13042176, count: int = 45503): ...
