from _typeshed import Incomplete

from networkx.utils.backends import _dispatchable

@_dispatchable
def line_graph(G, create_using: Incomplete | None = None): ...
@_dispatchable
def inverse_line_graph(G): ...
