from _typeshed import Incomplete

class Record:
    __attributes__: Incomplete
    def __eq__(self, other): ...
    def __ne__(self, other): ...
    def __iter__(self): ...
    def __hash__(self): ...
