from .bsnlp import load_bsnlp as load_bsnlp
from .buriy import *
from .corpora import load_corpora as load_corpora
from .factru import load_factru as load_factru
from .gareev import load_gareev as load_gareev
from .gramru import load_gramru as load_gramru
from .lenta import load_lenta as load_lenta, load_lenta2 as load_lenta2
from .librusec import load_librusec as load_librusec
from .mokoron import *
from .morphoru import *
from .ne5 import load_ne5 as load_ne5
from .ods import *
from .omnia import load_omnia as load_omnia
from .persons import load_persons as load_persons
from .ria import *
from .rudrec import load_rudrec as load_rudrec
from .russe import *
from .simlex import load_simlex as load_simlex
from .taiga import *
from .toloka import load_ruadrect as load_ruadrect, load_toloka_lrwc as load_toloka_lrwc
from .ud import *
from .wiki import load_wiki as load_wiki
from .wikiner import load_wikiner as load_wikiner
