from networkx.utils.backends import _dispatchable

@_dispatchable
def is_arborescence(G): ...
@_dispatchable
def is_branching(G): ...
@_dispatchable
def is_forest(G): ...
@_dispatchable
def is_tree(G): ...
