from _typeshed import Incomplete
from typing import Final

__version__: Final[str]

# NOTE: All the attributes in this module are Final
#       rl_config is the place to make changes
allowTableBoundsErrors: Final[int]
shapeChecking: Final[int]
defaultEncoding: Final[str]
defaultGraphicsFontName: Final[str]
pageCompression: Final[int]
useA85: Final[int]
defaultPageSize: Final[str]
defaultImageCaching: Final[int]
warnOnMissingFontGlyphs: Final[int]
verbose: Final[int]
showBoundary: Final[int]
emptyTableAction: Final[str]
invariant: Final[int]
eps_preview_transparent: Final[Incomplete]
eps_preview: Final[int]
eps_ttf_embed: Final[int]
eps_ttf_embed_uid: Final[int]
overlapAttachedSpace: Final[int]
longTableOptimize: Final[int]
autoConvertEncoding: Final[int]
_FUZZ: Final[float]
wrapA85: Final[int]
fsEncodings: Final[Incomplete]
odbc_driver: Final[str]
platypus_link_underline: Final[int]
canvas_basefontname: Final[str]
allowShortTableRows: Final[int]
imageReaderFlags: Final[int]
paraFontSizeHeightOffset: Final[int]
canvas_baseColor: Final[Incomplete]
ignoreContainerActions: Final[int]
ttfAsciiReadable: Final[int]
pdfMultiLine: Final[int]
pdfComments: Final[int]
debug: Final[int]
rtlSupport: Final[int]
listWrapOnFakeWidth: Final[int]
underlineWidth: Final[str]
underlineOffset: Final[str]
underlineGap: Final[str]
strikeWidth: Final[str]
strikeOffset: Final[str]
strikeGap: Final[str]
decimalSymbol: Final[str]
errorOnDuplicatePageLabelPage: Final[int]
autoGenerateMissingTTFName: Final[int]
allowTTFSubsetting: Final[Incomplete]
spaceShrinkage: Final[float]
hyphenationLang: Final[str]
uriWasteReduce: Final[int]
embeddedHyphenation: Final[int]
hyphenationMinWordLength: Final[int]
reserveTTFNotdef: Final[int]
documentLang: Final[Incomplete]
encryptionStrength: Final[int]
trustedHosts: Final[Incomplete]
trustedSchemes: Final[Incomplete]
renderPMBackend: Final[str]
xmlParser: Final[str]
textPaths: Final[str]
toColorCanUse: Final[str]
defCWRF: Final[float]
T1SearchPath: Final[Incomplete]
TTFSearchPath: Final[Incomplete]
CMapSearchPath: Final[Incomplete]
shapedFontGlob: Final[Incomplete | None]
