from _typeshed import Incomplete

PORT_SPEC: Incomplete

def add_port_mapping(port_bindings, internal_port, external) -> None: ...
def add_port(port_bindings, internal_port_range, external_range) -> None: ...
def build_port_bindings(ports): ...
def port_range(start, end, proto, randomly_available_port: bool = False): ...
def split_port(port): ...
