def fp_str(*a): ...
def unicode2T1(utext, fonts): ...
def instanceStringWidthT1(self, text, size, encoding: str = "utf8"): ...
def instanceStringWidthTTF(self, text, size, encoding: str = "utf8"): ...
def hex32(i): ...
def add32(x, y): ...
def calcChecksum(data): ...
def escapePDF(s): ...
def asciiBase85Encode(input): ...
def asciiBase85Decode(input): ...
def sameFrag(f, g): ...
