from _typeshed import Incomplete

__all__ = ["load_taiga_fontanka_metas", "load_taiga_fontanka"]

def load_taiga_fontanka_metas(path, offset: int = 0, count=13): ...
def load_taiga_fontanka(path, metas: Incomplete | None = None, offset: int = 306359296, count: int = 342683): ...
