from _typeshed import Incomplete

from networkx.utils.backends import _dispatchable

@_dispatchable
def reciprocity(G, nodes: Incomplete | None = None): ...
@_dispatchable
def overall_reciprocity(G): ...
